@@ -65,10 +65,10 @@ static const QVector<QString> responseTypeNames = {
 
 bool ewsXmlBoolReader(QXmlStreamReader &reader, QVariant &val)
 {
-    QString elmText = reader.readElementText();
+    const QString elmText = reader.readElementText();
     if (reader.error() != QXmlStreamReader::NoError) {
         qCWarningNC(EWSCLI_LOG) << QStringLiteral("Error reading %1 element")
-                                .arg(reader.name().toString());
+            .arg(reader.name().toString());
         reader.skipCurrentElement();
         return false;
     }
@@ -78,7 +78,7 @@ bool ewsXmlBoolReader(QXmlStreamReader &reader, QVariant &val)
         val = false;
     } else {
         qCWarningNC(EWSCLI_LOG) << QStringLiteral("Unexpected invalid boolean value in %1 element:")
-                                .arg(reader.name().toString())
+            .arg(reader.name().toString())
                                 << elmText;
         return false;
     }
@@ -99,7 +99,7 @@ bool ewsXmlBase64Reader(QXmlStreamReader &reader, QVariant &val)
     val = QByteArray::fromBase64(reader.readElementText().toLatin1());
     if (reader.error() != QXmlStreamReader::NoError) {
         qCWarningNC(EWSCLI_LOG) << QStringLiteral("Failed to read %1 element - invalid content.")
-                                .arg(elmName);
+            .arg(elmName);
         reader.skipCurrentElement();
         return false;
     }
@@ -120,7 +120,7 @@ bool ewsXmlIdReader(QXmlStreamReader &reader, QVariant &val)
     EwsId id = EwsId(reader);
     if (id.type() == EwsId::Unspecified) {
         qCWarningNC(EWSCLI_LOG) << QStringLiteral("Failed to read %1 element - invalid content.")
-                                .arg(elmName);
+            .arg(elmName);
         reader.skipCurrentElement();
         return false;
     }
@@ -147,7 +147,7 @@ bool ewsXmlTextReader(QXmlStreamReader &reader, QVariant &val)
     val = reader.readElementText();
     if (reader.error() != QXmlStreamReader::NoError) {
         qCWarningNC(EWSCLI_LOG) << QStringLiteral("Failed to read %1 element - invalid content.")
-                                .arg(elmName);
+            .arg(elmName);
         reader.skipCurrentElement();
         return false;
     }
@@ -168,7 +168,7 @@ bool ewsXmlUIntReader(QXmlStreamReader &reader, QVariant &val)
     val = reader.readElementText().toUInt(&ok);
     if (reader.error() != QXmlStreamReader::NoError || !ok) {
         qCWarningNC(EWSCLI_LOG) << QStringLiteral("Failed to read %1 element - invalid content.")
-                                .arg(elmName);
+            .arg(elmName);
         return false;
     }
     return true;
@@ -187,7 +187,7 @@ bool ewsXmlDateTimeReader(QXmlStreamReader &reader, QVariant &val)
     QDateTime dt = QDateTime::fromString(reader.readElementText(), Qt::ISODate);
     if (reader.error() != QXmlStreamReader::NoError || !dt.isValid()) {
         qCWarningNC(EWSCLI_LOG) << QStringLiteral("Failed to read %1 element - invalid content.")
-                                .arg(elmName);
+            .arg(elmName);
         return false;
     }
     val = QVariant::fromValue<QDateTime>(dt);
@@ -200,7 +200,7 @@ bool ewsXmlItemReader(QXmlStreamReader &reader, QVariant &val)
     EwsItem item = EwsItem(reader);
     if (!item.isValid()) {
         qCWarningNC(EWSCLI_LOG) << QStringLiteral("Failed to read %1 element - invalid content.")
-                                .arg(elmName);
+            .arg(elmName);
         reader.skipCurrentElement();
         return false;
     }
@@ -214,7 +214,7 @@ bool ewsXmlFolderReader(QXmlStreamReader &reader, QVariant &val)
     EwsFolder folder = EwsFolder(reader);
     if (!folder.isValid()) {
         qCWarningNC(EWSCLI_LOG) << QStringLiteral("Failed to read %1 element - invalid content.")
-                                .arg(elmName);
+            .arg(elmName);
         reader.skipCurrentElement();
         return false;
     }
@@ -228,7 +228,7 @@ bool ewsXmlEnumReader(QXmlStreamReader &reader, QVariant &val, const QVector<QSt
     QString text = reader.readElementText();
     if (reader.error() != QXmlStreamReader::NoError) {
         qCWarningNC(EWSCLI_LOG) << QStringLiteral("Failed to read %1 element - invalid content.")
-                                .arg(elmName);
+            .arg(elmName);
         reader.skipCurrentElement();
         return false;
     }
@@ -243,7 +243,7 @@ bool ewsXmlEnumReader(QXmlStreamReader &reader, QVariant &val, const QVector<QSt
 
     if (it == items.cend()) {
         qCWarningNC(EWSCLI_LOG) << QStringLiteral("Failed to read %1 element - unknown value %2.")
-                                .arg(elmName).arg(text);
+            .arg(elmName).arg(text);
         return false;
     }
     return true;
@@ -274,7 +274,7 @@ bool ewsXmlResponseTypeReader(QXmlStreamReader &reader, QVariant &val)
     return ewsXmlEnumReader(reader, val, responseTypeNames);
 }
 
-template <>
+template<>
 QString readXmlElementValue(QXmlStreamReader &reader, bool &ok, const QString &parentElement)
 {
     ok = true;
@@ -282,7 +282,7 @@ QString readXmlElementValue(QXmlStreamReader &reader, bool &ok, const QString &p
     QString val = reader.readElementText();
     if (reader.error() != QXmlStreamReader::NoError) {
         qCWarningNC(EWSCLI_LOG) << QStringLiteral("Failed to read %1 element - invalid %2 element.")
-                                .arg(parentElement).arg(elmName.toString());
+            .arg(parentElement).arg(elmName.toString());
         reader.skipCurrentElement();
         val.clear();
         ok = false;
@@ -291,7 +291,7 @@ QString readXmlElementValue(QXmlStreamReader &reader, bool &ok, const QString &p
     return val;
 }
 
-template <>
+template<>
 int readXmlElementValue(QXmlStreamReader &reader, bool &ok, const QString &parentElement)
 {
     QStringRef elmName = reader.name();
@@ -301,14 +301,14 @@ int readXmlElementValue(QXmlStreamReader &reader, bool &ok, const QString &paren
         val = valStr.toInt(&ok);
         if (!ok) {
             qCWarningNC(EWSCLI_LOG) << QStringLiteral("Failed to read %1 element - invalid %2 element.")
-                                    .arg(parentElement).arg(elmName.toString());
+                .arg(parentElement).arg(elmName.toString());
         }
     }
 
     return val;
 }
 
-template <>
+template<>
 long readXmlElementValue(QXmlStreamReader &reader, bool &ok, const QString &parentElement)
 {
     QStringRef elmName = reader.name();
@@ -318,14 +318,14 @@ long readXmlElementValue(QXmlStreamReader &reader, bool &ok, const QString &pare
         val = valStr.toLong(&ok);
         if (!ok) {
             qCWarningNC(EWSCLI_LOG) << QStringLiteral("Failed to read %1 element - invalid %2 element.")
-                                    .arg(parentElement).arg(elmName.toString());
+                .arg(parentElement).arg(elmName.toString());
         }
     }
 
     return val;
 }
 
-template <>
+template<>
 QDateTime readXmlElementValue(QXmlStreamReader &reader, bool &ok, const QString &parentElement)
 {
     QStringRef elmName = reader.name();
@@ -335,7 +335,7 @@ QDateTime readXmlElementValue(QXmlStreamReader &reader, bool &ok, const QString
         val = QDateTime::fromString(valStr, Qt::ISODate);
         if (!val.isValid()) {
             qCWarningNC(EWSCLI_LOG) << QStringLiteral("Failed to read %1 element - invalid %2 element.")
-                                    .arg(parentElement).arg(elmName.toString());
+                .arg(parentElement).arg(elmName.toString());
             ok = false;
         }
     }
@@ -343,7 +343,7 @@ QDateTime readXmlElementValue(QXmlStreamReader &reader, bool &ok, const QString
     return val;
 }
 
-template <>
+template<>
 bool readXmlElementValue(QXmlStreamReader &reader, bool &ok, const QString &parentElement)
 {
     QStringRef elmName = reader.name();
@@ -356,7 +356,7 @@ bool readXmlElementValue(QXmlStreamReader &reader, bool &ok, const QString &pare
             val = false;
         } else {
             qCWarningNC(EWSCLI_LOG) << QStringLiteral("Failed to read %1 element - invalid %2 element.")
-                                    .arg(parentElement).arg(elmName.toString());
+                .arg(parentElement).arg(elmName.toString());
             ok = false;
         }
     }
@@ -364,7 +364,7 @@ bool readXmlElementValue(QXmlStreamReader &reader, bool &ok, const QString &pare
     return val;
 }
 
-template <>
+template<>
 QByteArray readXmlElementValue(QXmlStreamReader &reader, bool &ok, const QString &parentElement)
 {
     QString valStr = readXmlElementValue<QString>(reader, ok, parentElement);
@@ -377,5 +377,3 @@ QByteArray readXmlElementValue(QXmlStreamReader &reader, bool &ok, const QString
 
     return val;
 }
-
-
